#!/bin/sh
#
# chkconfig: 345 99 80
# description: Starts and stops the Dynamic dns client daemon
#
# pidfile: /var/run/dyndn.pid
#
# Source function library.
if [ -f /etc/init.d/functions ] ; then
  . /etc/init.d/functions
elif [ -f /etc/rc.d/init.d/functions ] ; then
  . /etc/rc.d/init.d/functions
else
  exit 0
fi

# Avoid using root's TMPDIR
unset TMPDIR

# Source networking configuration.
. /etc/sysconfig/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

RETVAL=0

start() {
	if [ -f /var/run/dyndn.pid ] ; then
		echo "dyndn client daemon already started" && exit 0
	fi
	echo -n $"Starting dyndn client daemon: "
	daemon dyndn
	echo
	RETVAL=$?
	/sbin/pidof dyndn > /var/run/dyndn.pid
}	

stop() {
	if [ -f /var/run/dyndn.pid ] ; then
		echo -n $"Stopping dyndn client daemon: "
		killproc dyndn -TERM
		echo
		RETVAL=$?
		rm -f /var/run/dyndn.pid
	else
		echo "dyndn client daemon is not running" && exit 0
	fi
	return $RETVAL
}	

restart() {
	stop
	sleep 1
	start
}	

case "$1" in
  start)
  	start
	;;
  stop)
  	stop
	;;
  restart)
  	restart
	;;
  *)
	echo $"Usage: $0 {start|stop|restart}"
	exit 1
esac

exit $?
